@@ -1,9 +1,9 @@
 from __future__ import print_function
 
 import logging
+import os
 
 from designateclient import exceptions
-from designateclient import shell
 from designateclient.v2 import client
 
 from keystoneauth1.identity import generic
@@ -13,10 +13,10 @@ from keystoneauth1 import session as keystone_session
 logging.basicConfig(level='DEBUG')
 
 auth = generic.Password(
-    auth_url=shell.env('OS_AUTH_URL'),
-    username=shell.env('OS_USERNAME'),
-    password=shell.env('OS_PASSWORD'),
-    project_name=shell.env('OS_PROJECT_NAME'),
+    auth_url=os.environ.get('OS_AUTH_URL'),
+    username=os.environ.get('OS_USERNAME'),
+    password=os.environ.get('OS_PASSWORD'),
+    project_name=os.environ.get('OS_PROJECT_NAME'),
     project_domain_id='default',
     user_domain_id='default')
 
